@@ -41,8 +41,6 @@
 
 #define KI18N_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KI18N_NO_DEPRECATED) && !defined(KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KI18N_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KI18N_NO_DEPRECATED
-#  define KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef KI18N_NO_DEPRECATED_WARNINGS
 #  define KI18N_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KI18N_DEPRECATED_WARNINGS_SINCE KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KI18N_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KI18N_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KI18N_DEPRECATED
-#  define KI18N_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KI18N_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KI18N_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
